summaryrefslogtreecommitdiff
path: root/nuttx/configs/pcduino-a10/src/a1x_buttons.c
diff options
context:
space:
mode:
Diffstat (limited to 'nuttx/configs/pcduino-a10/src/a1x_buttons.c')
-rw-r--r--nuttx/configs/pcduino-a10/src/a1x_buttons.c6
1 files changed, 3 insertions, 3 deletions
diff --git a/nuttx/configs/pcduino-a10/src/a1x_buttons.c b/nuttx/configs/pcduino-a10/src/a1x_buttons.c
index 6cae19a93..5ea4359b3 100644
--- a/nuttx/configs/pcduino-a10/src/a1x_buttons.c
+++ b/nuttx/configs/pcduino-a10/src/a1x_buttons.c
@@ -77,7 +77,7 @@ static xcpt_t g_irqbutton[BOARD_NBUTTONS];
* Description:
* board_button_initialize() must be called to initialize button resources. After
* that, board_buttons() may be called to collect the current state of all
* buttons or up_irqbutton() may be called to register button interrupt
* handlers.
*
****************************************************************************/
@@ -104,7 +104,7 @@ uint8_t board_buttons(void)
}
/****************************************************************************
- * Name: up_irqbutton
+ * Name: board_button_irq
*
* Description:
* This function may be called to register an interrupt handler that will
@@ -119,7 +119,7 @@ uint8_t board_buttons(void)
****************************************************************************/
#ifdef CONFIG_ARCH_IRQBUTTONS
-xcpt_t up_irqbutton(int id, xcpt_t irqhandler)
+xcpt_t board_button_irq(int id, xcpt_t irqhandler)
{
xcpt_t oldhandler = NULL;
@@ -77,7 +77,7 @@ static xcpt_t g_irqbutton[BOARD_NBUTTONS];
* board_button_initialize() must be called to initialize button resources. After
* that, board_buttons() may be called to collect the current state of all
- * buttons or up_irqbutton() may be called to register button interrupt
+ * buttons or board_button_irq() may be called to register button interrupt
* handlers.
*